@@ -41,12 +41,14 @@ ConnectDialog::ConnectDialog(QWidget *parent) :
     m_stackedLayout = new QStackedLayout();
 
     XbmcDiscovery *discovery = new XbmcDiscovery(this);
+    discovery->setContinuousDiscovery(true);
 
     m_hostView = new QListView();
     m_hostView->setModel(Xbmc::instance()->hostModel());
     m_stackedLayout->addWidget(m_hostView);
 
-    QLabel *infoLabel = new QLabel("No XBMC hosts found.\nMake sure that remote controlling\ncapabilities are enabled and\nannounced using Zeroconf\nor connect to the host manually.");
+    QLabel *infoLabel = new QLabel(tr("Searching for XBMC hosts. Make sure that remote controlling capabilities in XBMC are enabled and announced using Zeroconf. If you don't use Zeroconf, add a host manually."));
+    infoLabel->setWordWrap(true);
     infoLabel->setAlignment(Qt::AlignCenter);
     m_stackedLayout->addWidget(infoLabel);
 
@@ -64,17 +66,23 @@ ConnectDialog::ConnectDialog(QWidget *parent) :
     setLayout(vLayout);
 #endif
 
-    m_manualLayout->addWidget(new QLabel("Host:"), 0, 0);
+    m_manualLayout->addWidget(new QLabel(tr("Host:")), 0, 0);
 
     m_hostName = new QLineEdit();
     m_manualLayout->addWidget(m_hostName, 0, 1);
 
-    m_manualLayout->addWidget(new QLabel("Http Port:"), 1, 0);
+    m_manualLayout->addWidget(new QLabel(tr("HTTP Port:")), 1, 0);
 
     m_port = new QLineEdit();
     m_port->setValidator(new QIntValidator());
     m_manualLayout->addWidget(m_port, 1, 1);
 
+    m_manualLayout->addWidget(new QLabel(tr("MAC Address (optional):")), 2, 0);
+
+    m_mac = new QLineEdit();
+    m_mac->setInputMask("HH:HH:HH:HH:HH:HH;_");
+    m_manualLayout->addWidget(m_mac, 2, 1);
+
 //    gridLayout->addWidget(new QLabel("Username:"), 2, 0);
 
 //    m_userName = new QLineEdit(Xbmc::instance()->username());
@@ -93,10 +101,15 @@ ConnectDialog::ConnectDialog(QWidget *parent) :
     m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal);
     vLayout->addWidget(m_buttonBox);
 #endif
-    m_manualButton = m_buttonBox->addButton("Manual connection", QDialogButtonBox::ActionRole);
-    connect(m_manualButton, SIGNAL(clicked()), SLOT(showManualLayout()));
+    m_buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Connect"));
     m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
 
+    m_manualButton = m_buttonBox->addButton(tr("Add Host"), QDialogButtonBox::ActionRole);
+    connect(m_manualButton, SIGNAL(clicked()), SLOT(showManualLayout()));
+
+    m_removeButton = m_buttonBox->addButton(tr("Remove Host"), QDialogButtonBox::ResetRole);
+    connect(m_removeButton, SIGNAL(clicked()), SLOT(removeHost()));
+    m_removeButton->setEnabled(false);
 
     connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
@@ -120,6 +133,7 @@ void ConnectDialog::accept()
         host.setHostname(m_hostName->text());
         host.setAddress(m_hostName->text());
         host.setPort(m_port->text().toInt());
+        host.setHwAddr(m_mac->text());
         int newHostIndex = Xbmc::instance()->hostModel()->insertOrUpdateHost(host);
         Xbmc::instance()->hostModel()->connectToHost(newHostIndex);
     }
@@ -130,14 +144,14 @@ void ConnectDialog::showManualLayout()
 {
     if(m_stackedLayout->currentIndex() != 2) {
         m_stackedLayout->setCurrentIndex(2);
-        m_manualButton->setText("Show host list");
+        m_manualButton->setText(tr("Back"));
     } else {
         if(Xbmc::instance()->hostModel()->rowCount(QModelIndex()) > 0) {
             m_stackedLayout->setCurrentIndex(0);
         } else {
             m_stackedLayout->setCurrentIndex(1);
         }
-        m_manualButton->setText("Manual connection");
+        m_manualButton->setText(tr("Add Host"));
     }
     enableOkButton();
 }
@@ -152,12 +166,25 @@ void ConnectDialog::enableOkButton()
     switch(m_stackedLayout->currentIndex()) {
     case 0:
         m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(m_hostView->currentIndex().isValid());
+        m_removeButton->setVisible(true);
+        m_removeButton->setEnabled(m_hostView->currentIndex().isValid());
         break;
     case 1:
         m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
+        m_removeButton->setVisible(false);
         break;
     case 2:
         m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
+        m_removeButton->setVisible(false);
         break;
     }
 }
+
+void ConnectDialog::removeHost()
+{
+    Xbmc::instance()->hostModel()->removeHost(m_hostView->currentIndex().row());
+    enableOkButton();
+    if(Xbmc::instance()->hostModel()->rowCount(QModelIndex()) == 0) {
+        m_stackedLayout->setCurrentIndex(1);
+    }
+}
