@@ -75,7 +75,7 @@ QNetworkAccessManager *nam()
     return instance()->nam();
 }
 
-QDate xbmcVersion()
+int xbmcVersion()
 {
     return instance()->xbmcVersion();
 }
@@ -88,8 +88,8 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
     QObject(parent),
     m_commandId(0),
     m_versionRequestId(-1),
-    m_connected(false),
-    m_host(0)
+    m_host(0),
+    m_connected(false)
 {
     m_socket = new QTcpSocket();
     m_notifier = new XbmcConnection::Notifier();
@@ -118,7 +118,7 @@ void XbmcConnectionPrivate::connect(XbmcHost *host)
     // We connect to telnet on port 9090 for the announcements
     m_socket->connectToHost(host->address(), 9090);
 
-    m_connectionError = "Connecting to " + host->hostname() + "...";
+    m_connectionError = tr("Connecting to %1...").arg(host->hostname());
     emit m_notifier->connectionChanged();
 }
 
@@ -132,11 +132,7 @@ void XbmcConnectionPrivate::slotConnected()
     xDebug(XDAREA_CONNECTION) << "Connected to remote host. Asking for version...";
 
     m_versionRequestId = m_commandId++;
-    QVariantMap params;
-    QVariantList properties;
-    properties.append("version");
-    params.insert("properties", properties);
-    Command cmd(m_versionRequestId, "Application.GetProperties", params);
+    Command cmd(m_versionRequestId, "JSONRPC.Version");
     m_commandQueue.prepend(cmd);
     sendNextCommand2();
 }
@@ -148,7 +144,7 @@ void XbmcConnectionPrivate::slotDisconnected()
     }
     xDebug(XDAREA_CONNECTION) << "Disconnected";
     m_connected = false;
-    m_connectionError = "The connection has been disconnected";
+    m_connectionError = tr("The connection has been disconnected");
     emit m_notifier->connectionChanged();
 }
 
@@ -156,7 +152,7 @@ void XbmcConnectionPrivate::socketError()
 {
     QString errorString = m_socket->errorString();
     xDebug(XDAREA_CONNECTION) << "connection error:" << errorString;
-    m_connectionError = "Connection failed: " + errorString;
+    m_connectionError = tr("Connection failed: %1").arg(errorString);
     emit m_notifier->connectionChanged();
 }
 
@@ -203,7 +199,7 @@ void XbmcConnectionPrivate::replyReceived()
     QString commands = reply->readAll();
     if(reply->error() != QNetworkReply::NoError) {
         m_socket->disconnectFromHost();
-        m_connectionError = "Connection failed: " + reply->errorString();
+        m_connectionError = tr("Connection failed: %1").arg(reply->errorString());
         emit m_notifier->connectionChanged();
     }
 
@@ -242,21 +238,16 @@ void XbmcConnectionPrivate::replyReceived()
         if(rsp.value("id").toInt() == m_versionRequestId) {
             // If the remote xbmc has the version field not compiled in, assume its the latest known one
             xDebug(XDAREA_CONNECTION) << "Parsing XBMC version:" << rsp.value("result").toMap().value("version");
-            if(rsp.value("result").toMap().value("version").toMap().value("revision").toString() == "Unknown") {
-                m_xbmcVersion.setDate(2011, 10, 8);
-                qDebug() << "WARNING: Cannot determine Xbmc version. Assuming" << m_xbmcVersion.toString(Qt::SystemLocaleLongDate);
-            } else {
-                m_xbmcVersion.setDate(rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(4).toInt(),
-                                      rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(6).right(2).toInt(),
-                                      rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(8).right(2).toInt());
-                xDebug(XDAREA_CONNECTION) << "Connected to XBMC version:" << m_xbmcVersion.toString(Qt::SystemLocaleLongDate);
-            }
-            if(m_xbmcVersion <= QDate(2011, 9, 23)) {
+            m_xbmcVersion = rsp.value("result").toMap().value("version").toInt();
+            if(m_xbmcVersion < 3) {
                 qDebug() << "WARNING! XBMC is too old or version field not valid! Some features might not work";
+                m_connected = false;
+                m_connectionError = tr("Xbmcremote is designed to work with XBMC Eden (v11.0). It seems you have connected to an older version of XMBC. Please upgrade XBMC in order to use Xbmcremote.");
+            } else {
+                sendNextCommand2();
+                m_connected = true;
+                m_connectionError.clear();
             }
-            sendNextCommand2();
-            m_connected = true;
-            m_connectionError.clear();
             emit m_notifier->connectionChanged();
             return;
         }
@@ -405,7 +396,7 @@ void XbmcConnectionPrivate::clearPending()
     xDebug(XDAREA_CONNECTION) << "timeouttimer hit for comman" << m_commandId;
     if(m_commandId == m_versionRequestId) {
         xDebug(XDAREA_CONNECTION) << "cannot ask for remote version... ";
-        m_connectionError = "Connection to " + m_host->hostname() + " timed out...";
+        m_connectionError = tr("Connection to %1 timed out...").arg(m_host->hostname());
         emit m_notifier->connectionChanged();
         m_commandQueue.clear();
     }
@@ -458,7 +449,7 @@ QNetworkAccessManager *XbmcConnectionPrivate::nam()
     return m_network;
 }
 
-QDate XbmcConnectionPrivate::xbmcVersion()
+int XbmcConnectionPrivate::xbmcVersion()
 {
     return m_xbmcVersion;
 }
